summaryrefslogtreecommitdiff
path: root/Modules/CheckFortranCompilerFlag.cmake
diff options
context:
space:
mode:
authorMark Abraham <mark.j.abraham@gmail.com>2015-02-24 14:20:16 +0100
committerBrad King <brad.king@kitware.com>2015-02-24 09:45:19 -0500
commit5d5067ae57c9d02656a54076cdf121c7084a4de3 (patch)
treebfbe84f773aa8c2c7770b942fe383d7cde8f9362 /Modules/CheckFortranCompilerFlag.cmake
parentac80f0f95fc7cfbad17c2a5656a87e346b9f298a (diff)
downloadcmake-5d5067ae57c9d02656a54076cdf121c7084a4de3.tar.gz
Check*CompilerFlag: Refactor method used to pass flags
Refactor the Check*CompilerFlag modules to pass the flags to Check*SourceCompiles using CMAKE_REQUIRED_FLAGS instead of CMAKE_REQUIRED_DEFINITIONS. Both end up being used, but the variable for "FLAGS" is more precise.
Diffstat (limited to 'Modules/CheckFortranCompilerFlag.cmake')
-rw-r--r--Modules/CheckFortranCompilerFlag.cmake8
1 files changed, 4 insertions, 4 deletions
diff --git a/Modules/CheckFortranCompilerFlag.cmake b/Modules/CheckFortranCompilerFlag.cmake
index 53fd8d64da..c476661434 100644
--- a/Modules/CheckFortranCompilerFlag.cmake
+++ b/Modules/CheckFortranCompilerFlag.cmake
@@ -13,7 +13,7 @@
# Will be created as an internal cache variable.
#
# This internally calls the check_fortran_source_compiles macro and
# sets CMAKE_REQUIRED_DEFINITIONS to <flag>. See help for
# CheckFortranSourceCompiles for a listing of variables that can
# otherwise modify the build. The result only tells that the compiler
# does not give an error message when it encounters the flag. If the
@@ -40,8 +40,8 @@ include(CheckFortranSourceCompiles)
include(CMakeCheckCompilerFlagCommonPatterns)
macro (CHECK_Fortran_COMPILER_FLAG _FLAG _RESULT)
- set(SAFE_CMAKE_REQUIRED_DEFINITIONS "${CMAKE_REQUIRED_DEFINITIONS}")
- set(CMAKE_REQUIRED_DEFINITIONS "${_FLAG}")
+ set(SAFE_CMAKE_REQUIRED_FLAGS "${CMAKE_REQUIRED_FLAGS}")
+ set(CMAKE_REQUIRED_FLAGS "${_FLAG}")
# Normalize locale during test compilation.
set(_CheckFortranCompilerFlag_LOCALE_VARS LC_ALL LC_MESSAGES LANG)
@@ -62,5 +62,5 @@ macro (CHECK_Fortran_COMPILER_FLAG _FLAG _RESULT)
unset(_CheckFortranCompilerFlag_LOCALE_VARS)
unset(_CheckFortranCompilerFlag_COMMON_PATTERNS)
- set (CMAKE_REQUIRED_DEFINITIONS "${SAFE_CMAKE_REQUIRED_DEFINITIONS}")
+ set (CMAKE_REQUIRED_FLAGS "${SAFE_CMAKE_REQUIRED_FLAGS}")
endmacro ()
@@ -13,7 +13,7 @@
#
# This internally calls the check_fortran_source_compiles macro and
-# sets CMAKE_REQUIRED_DEFINITIONS to <flag>. See help for
+# sets CMAKE_REQUIRED_FLAGS to <flag>. See help for
# CheckFortranSourceCompiles for a listing of variables that can
# otherwise modify the build. The result only tells that the compiler